@@ -277,6 +277,9 @@ class H264Encoder(Encoder):
             self.buffer_pts = None
             self.codec = None
 
+        # reset the picture type, otherwise no B-frames are produced
+        frame.pict_type = av.video.frame.PictureType.NONE
+
         if self.codec is None:
             try:
                 self.codec, self.codec_buffering = create_encoder_context(
@@ -292,7 +295,7 @@ class H264Encoder(Encoder):
 
         data_to_send = b""
         for package in self.codec.encode(frame):
-            package_bytes = package.to_bytes()
+            package_bytes = bytes(package)
             if self.codec_buffering:
                 # delay sending to ensure we accumulate all packages
                 # for a given PTS
