@@ -2,7 +2,6 @@ import asyncio
 import copy
 import logging
 import uuid
-from collections import OrderedDict
 from typing import Dict, List, Optional, Set, Union
 
 from pyee.asyncio import AsyncIOEventEmitter
@@ -97,19 +96,7 @@ def find_common_codecs(
 
         # handle other codecs
         for codec in local_codecs:
-            if (
-                codec.mimeType.lower() == c.mimeType.lower()
-                and codec.clockRate == c.clockRate
-            ):
-                if codec.mimeType.lower() == "video/h264":
-                    # FIXME: check according to RFC 6184
-                    parameters_compatible = True
-                    for param in ["packetization-mode", "profile-level-id"]:
-                        if c.parameters.get(param) != codec.parameters.get(param):
-                            parameters_compatible = False
-                    if not parameters_compatible:
-                        continue
-
+            if is_codec_compatible(codec, c):
                 codec = copy.deepcopy(codec)
                 if c.payloadType in rtp.DYNAMIC_PAYLOAD_TYPES:
                     codec.payloadType = c.payloadType
@@ -134,6 +121,31 @@ def find_common_header_extensions(
     return common
 
 
+def is_codec_compatible(a: RTCRtpCodecParameters, b: RTCRtpCodecParameters) -> bool:
+    if a.mimeType.lower() != b.mimeType.lower() or a.clockRate != b.clockRate:
+        return False
+
+    if a.mimeType.lower() == "video/h264":
+
+        def packetization(c: RTCRtpCodecParameters):
+            return c.parameters.get("packetization-mode", "0")
+
+        def profile(c: RTCRtpCodecParameters):
+            # for backwards compatibility with older versions of WebRTC,
+            # consider the absence of a profile-level-id parameter to mean
+            # "constrained baseline level 3.1"
+            return sdp.parse_h264_profile_level_id(
+                c.parameters.get("profile-level-id", "42E01F")
+            )[0]
+
+        try:
+            return packetization(a) == packetization(b) and profile(a) == profile(b)
+        except ValueError:
+            return False
+
+    return True
+
+
 def add_transport_description(
     media: sdp.MediaDescription, dtlsTransport: RTCDtlsTransport
 ) -> None:
@@ -1104,7 +1116,7 @@ class RTCPeerConnection(AsyncIOEventEmitter):
             rtcp=media.rtp.rtcp,
         )
         if len(media.ssrc):
-            encodings: OrderedDict[int, RTCRtpDecodingParameters] = OrderedDict()
+            encodings: Dict[int, RTCRtpDecodingParameters] = {}
             for codec in transceiver._codecs:
                 if is_rtx(codec):
                     if codec.parameters["apt"] in encodings and len(media.ssrc) == 2:
