@@ -4,7 +4,7 @@ import random
 import time
 import traceback
 import uuid
-from typing import Dict, List, Optional, Union
+from typing import Callable, Dict, List, Optional, Union
 
 from av import AudioFrame
 
@@ -18,6 +18,7 @@ from .rtp import (
     RTCP_PSFB_APP,
     RTCP_PSFB_PLI,
     RTCP_RTPFB_NACK,
+    RTP_HISTORY_SIZE,
     AnyRtcpPacket,
     RtcpByePacket,
     RtcpPsfbPacket,
@@ -40,7 +41,6 @@ from .utils import random16, random32, uint16_add, uint32_add
 
 logger = logging.getLogger(__name__)
 
-RTP_HISTORY_SIZE = 128
 RTT_ALPHA = 0.85
 
 
@@ -104,6 +104,13 @@ class RTCRtpSender:
         self.__packet_count = 0
         self.__rtt = None
 
+        # logging
+        self.__log_debug: Callable[..., None] = lambda *args: None
+        if logger.isEnabledFor(logging.DEBUG):
+            self.__log_debug = lambda msg, *args: logger.debug(
+                f"RTCRtpSender(%s) {msg}", self.__kind, *args
+            )
+
     @property
     def kind(self):
         return self.__kind
@@ -421,8 +428,5 @@ class RTCRtpSender:
         except ConnectionError:
             pass
 
-    def __log_debug(self, msg: str, *args) -> None:
-        logger.debug(f"RTCRtpSender(%s) {msg}", self.__kind, *args)
-
     def __log_warning(self, msg: str, *args) -> None:
         logger.warning(f"RTCRtpsender(%s) {msg}", self.__kind, *args)
