@@ -3,6 +3,8 @@ import io
 from contextlib import redirect_stderr
 from unittest import TestCase
 
+from av import Packet
+
 from aiortc.codecs import get_decoder, get_encoder, h264
 from aiortc.codecs.h264 import H264Decoder, H264Encoder, H264PayloadDescriptor
 from aiortc.jitterbuffer import JitterFrame
@@ -16,22 +18,15 @@ H264_CODEC = RTCRtpCodecParameters(
 )
 
 
-class DummyPacket:
-    def __init__(self, dts, pts):
-        self.dts = dts
-        self.pts = pts
-
-    def to_bytes(self):
-        return b""
-
-
 class FragmentedCodecContext:
     def __init__(self, orig):
         self.__orig = orig
 
     def encode(self, frame):
         packages = self.__orig.encode(frame)
-        packages.append(DummyPacket(packages[0].dts, packages[0].pts))
+        dummy = Packet()
+        dummy.pts = packages[0].pts
+        packages.append(dummy)
         return packages
 
     def __getattr__(self, name):
@@ -106,7 +101,7 @@ class H264PayloadDescriptorTest(TestCase):
 class H264Test(CodecTestCase):
     def test_decoder(self):
         decoder = get_decoder(H264_CODEC)
-        self.assertTrue(isinstance(decoder, H264Decoder))
+        self.assertIsInstance(decoder, H264Decoder)
 
         # decode junk
         with redirect_stderr(io.StringIO()):
@@ -115,7 +110,7 @@ class H264Test(CodecTestCase):
 
     def test_encoder(self):
         encoder = get_encoder(H264_CODEC)
-        self.assertTrue(isinstance(encoder, H264Encoder))
+        self.assertIsInstance(encoder, H264Encoder)
 
         frame = self.create_video_frame(width=640, height=480, pts=0)
         packages, timestamp = encoder.encode(frame)
@@ -131,7 +126,7 @@ class H264Test(CodecTestCase):
         h264.create_encoder_context = mock_create_encoder_context
         try:
             encoder = get_encoder(H264_CODEC)
-            self.assertTrue(isinstance(encoder, H264Encoder))
+            self.assertIsInstance(encoder, H264Encoder)
 
             frame = self.create_video_frame(width=640, height=480, pts=0)
             packages, timestamp = encoder.encode(frame)
@@ -145,7 +140,7 @@ class H264Test(CodecTestCase):
 
     def test_encoder_target_bitrate(self):
         encoder = get_encoder(H264_CODEC)
-        self.assertTrue(isinstance(encoder, H264Encoder))
+        self.assertIsInstance(encoder, H264Encoder)
         self.assertEqual(encoder.target_bitrate, 1000000)
 
         frame = self.create_video_frame(width=640, height=480, pts=0)
